SWDEV-339113 - update coordinate in HIP sample kernels (#2736)
Change-Id: I8ea179b4ba8f1c0ebec830a5aa5947e843f06e42
This commit is contained in:
committato da
GitHub
parent
7d7953c8e0
commit
dea8404361
@@ -37,8 +37,8 @@ THE SOFTWARE.
|
||||
|
||||
// Device (Kernel) function, it must be void
|
||||
__global__ void matrixTranspose(float* out, float* in, const int width) {
|
||||
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
|
||||
int y = hipBlockDim_y * hipBlockIdx_y + hipThreadIdx_y;
|
||||
int x = blockDim.x * blockIdx.x + threadIdx.x;
|
||||
int y = blockDim.y * blockIdx.y + threadIdx.y;
|
||||
|
||||
out[y * width + x] = in[x * width + y];
|
||||
}
|
||||
|
||||
Fai riferimento in un nuovo problema
Block a user